# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class UpdateContactDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "firstname": "str",
        "lastname": "str",
        "job_title": "str",
        "phone": "str",
        "mobile_phone": "str",
        "is_contact_person": "bool",
        "in_ignore_mode": "bool",
    }

    attribute_map = {
        "firstname": "Firstname",
        "lastname": "Lastname",
        "job_title": "JobTitle",
        "phone": "Phone",
        "mobile_phone": "MobilePhone",
        "is_contact_person": "IsContactPerson",
        "in_ignore_mode": "InIgnoreMode",
    }

    def __init__(
        self,
        firstname=None,
        lastname=None,
        job_title=None,
        phone=None,
        mobile_phone=None,
        is_contact_person=None,
        in_ignore_mode=None,
        _configuration=None,
    ):  # noqa: E501
        """UpdateContactDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._firstname = None
        self._lastname = None
        self._job_title = None
        self._phone = None
        self._mobile_phone = None
        self._is_contact_person = None
        self._in_ignore_mode = None
        self.discriminator = None

        if firstname is not None:
            self.firstname = firstname
        if lastname is not None:
            self.lastname = lastname
        if job_title is not None:
            self.job_title = job_title
        if phone is not None:
            self.phone = phone
        if mobile_phone is not None:
            self.mobile_phone = mobile_phone
        if is_contact_person is not None:
            self.is_contact_person = is_contact_person
        if in_ignore_mode is not None:
            self.in_ignore_mode = in_ignore_mode

    @property
    def firstname(self):
        """Gets the firstname of this UpdateContactDTO.  # noqa: E501


        :return: The firstname of this UpdateContactDTO.  # noqa: E501
        :rtype: str
        """
        return self._firstname

    @firstname.setter
    def firstname(self, firstname):
        """Sets the firstname of this UpdateContactDTO.


        :param firstname: The firstname of this UpdateContactDTO.  # noqa: E501
        :type: str
        """

        self._firstname = firstname

    @property
    def lastname(self):
        """Gets the lastname of this UpdateContactDTO.  # noqa: E501


        :return: The lastname of this UpdateContactDTO.  # noqa: E501
        :rtype: str
        """
        return self._lastname

    @lastname.setter
    def lastname(self, lastname):
        """Sets the lastname of this UpdateContactDTO.


        :param lastname: The lastname of this UpdateContactDTO.  # noqa: E501
        :type: str
        """

        self._lastname = lastname

    @property
    def job_title(self):
        """Gets the job_title of this UpdateContactDTO.  # noqa: E501


        :return: The job_title of this UpdateContactDTO.  # noqa: E501
        :rtype: str
        """
        return self._job_title

    @job_title.setter
    def job_title(self, job_title):
        """Sets the job_title of this UpdateContactDTO.


        :param job_title: The job_title of this UpdateContactDTO.  # noqa: E501
        :type: str
        """

        self._job_title = job_title

    @property
    def phone(self):
        """Gets the phone of this UpdateContactDTO.  # noqa: E501


        :return: The phone of this UpdateContactDTO.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this UpdateContactDTO.


        :param phone: The phone of this UpdateContactDTO.  # noqa: E501
        :type: str
        """

        self._phone = phone

    @property
    def mobile_phone(self):
        """Gets the mobile_phone of this UpdateContactDTO.  # noqa: E501


        :return: The mobile_phone of this UpdateContactDTO.  # noqa: E501
        :rtype: str
        """
        return self._mobile_phone

    @mobile_phone.setter
    def mobile_phone(self, mobile_phone):
        """Sets the mobile_phone of this UpdateContactDTO.


        :param mobile_phone: The mobile_phone of this UpdateContactDTO.  # noqa: E501
        :type: str
        """

        self._mobile_phone = mobile_phone

    @property
    def is_contact_person(self):
        """Gets the is_contact_person of this UpdateContactDTO.  # noqa: E501


        :return: The is_contact_person of this UpdateContactDTO.  # noqa: E501
        :rtype: bool
        """
        return self._is_contact_person

    @is_contact_person.setter
    def is_contact_person(self, is_contact_person):
        """Sets the is_contact_person of this UpdateContactDTO.


        :param is_contact_person: The is_contact_person of this UpdateContactDTO.  # noqa: E501
        :type: bool
        """

        self._is_contact_person = is_contact_person

    @property
    def in_ignore_mode(self):
        """Gets the in_ignore_mode of this UpdateContactDTO.  # noqa: E501


        :return: The in_ignore_mode of this UpdateContactDTO.  # noqa: E501
        :rtype: bool
        """
        return self._in_ignore_mode

    @in_ignore_mode.setter
    def in_ignore_mode(self, in_ignore_mode):
        """Sets the in_ignore_mode of this UpdateContactDTO.


        :param in_ignore_mode: The in_ignore_mode of this UpdateContactDTO.  # noqa: E501
        :type: bool
        """

        self._in_ignore_mode = in_ignore_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UpdateContactDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateContactDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateContactDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class TicketTimeEntriesQueryDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "ticket_id": "int",
        "work_hours_id": "int",
        "start_work_hour": "datetime",
        "end_work_hour": "datetime",
        "technician_contact_id": "int",
        "billiable": "bool",
        "on_customer_site": "bool",
        "description": "str",
        "technician_full_name": "str",
        "technician_email": "str",
    }

    attribute_map = {
        "ticket_id": "TicketID",
        "work_hours_id": "WorkHoursID",
        "start_work_hour": "StartWorkHour",
        "end_work_hour": "EndWorkHour",
        "technician_contact_id": "TechnicianContactID",
        "billiable": "Billiable",
        "on_customer_site": "OnCustomerSite",
        "description": "Description",
        "technician_full_name": "TechnicianFullName",
        "technician_email": "TechnicianEmail",
    }

    def __init__(
        self,
        ticket_id=None,
        work_hours_id=None,
        start_work_hour=None,
        end_work_hour=None,
        technician_contact_id=None,
        billiable=None,
        on_customer_site=None,
        description=None,
        technician_full_name=None,
        technician_email=None,
        _configuration=None,
    ):  # noqa: E501
        """TicketTimeEntriesQueryDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._ticket_id = None
        self._work_hours_id = None
        self._start_work_hour = None
        self._end_work_hour = None
        self._technician_contact_id = None
        self._billiable = None
        self._on_customer_site = None
        self._description = None
        self._technician_full_name = None
        self._technician_email = None
        self.discriminator = None

        if ticket_id is not None:
            self.ticket_id = ticket_id
        if work_hours_id is not None:
            self.work_hours_id = work_hours_id
        if start_work_hour is not None:
            self.start_work_hour = start_work_hour
        if end_work_hour is not None:
            self.end_work_hour = end_work_hour
        if technician_contact_id is not None:
            self.technician_contact_id = technician_contact_id
        if billiable is not None:
            self.billiable = billiable
        if on_customer_site is not None:
            self.on_customer_site = on_customer_site
        if description is not None:
            self.description = description
        if technician_full_name is not None:
            self.technician_full_name = technician_full_name
        if technician_email is not None:
            self.technician_email = technician_email

    @property
    def ticket_id(self):
        """Gets the ticket_id of this TicketTimeEntriesQueryDTO.  # noqa: E501


        :return: The ticket_id of this TicketTimeEntriesQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._ticket_id

    @ticket_id.setter
    def ticket_id(self, ticket_id):
        """Sets the ticket_id of this TicketTimeEntriesQueryDTO.


        :param ticket_id: The ticket_id of this TicketTimeEntriesQueryDTO.  # noqa: E501
        :type: int
        """

        self._ticket_id = ticket_id

    @property
    def work_hours_id(self):
        """Gets the work_hours_id of this TicketTimeEntriesQueryDTO.  # noqa: E501


        :return: The work_hours_id of this TicketTimeEntriesQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._work_hours_id

    @work_hours_id.setter
    def work_hours_id(self, work_hours_id):
        """Sets the work_hours_id of this TicketTimeEntriesQueryDTO.


        :param work_hours_id: The work_hours_id of this TicketTimeEntriesQueryDTO.  # noqa: E501
        :type: int
        """

        self._work_hours_id = work_hours_id

    @property
    def start_work_hour(self):
        """Gets the start_work_hour of this TicketTimeEntriesQueryDTO.  # noqa: E501


        :return: The start_work_hour of this TicketTimeEntriesQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._start_work_hour

    @start_work_hour.setter
    def start_work_hour(self, start_work_hour):
        """Sets the start_work_hour of this TicketTimeEntriesQueryDTO.


        :param start_work_hour: The start_work_hour of this TicketTimeEntriesQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._start_work_hour = start_work_hour

    @property
    def end_work_hour(self):
        """Gets the end_work_hour of this TicketTimeEntriesQueryDTO.  # noqa: E501


        :return: The end_work_hour of this TicketTimeEntriesQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._end_work_hour

    @end_work_hour.setter
    def end_work_hour(self, end_work_hour):
        """Sets the end_work_hour of this TicketTimeEntriesQueryDTO.


        :param end_work_hour: The end_work_hour of this TicketTimeEntriesQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._end_work_hour = end_work_hour

    @property
    def technician_contact_id(self):
        """Gets the technician_contact_id of this TicketTimeEntriesQueryDTO.  # noqa: E501


        :return: The technician_contact_id of this TicketTimeEntriesQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._technician_contact_id

    @technician_contact_id.setter
    def technician_contact_id(self, technician_contact_id):
        """Sets the technician_contact_id of this TicketTimeEntriesQueryDTO.


        :param technician_contact_id: The technician_contact_id of this TicketTimeEntriesQueryDTO.  # noqa: E501
        :type: int
        """

        self._technician_contact_id = technician_contact_id

    @property
    def billiable(self):
        """Gets the billiable of this TicketTimeEntriesQueryDTO.  # noqa: E501


        :return: The billiable of this TicketTimeEntriesQueryDTO.  # noqa: E501
        :rtype: bool
        """
        return self._billiable

    @billiable.setter
    def billiable(self, billiable):
        """Sets the billiable of this TicketTimeEntriesQueryDTO.


        :param billiable: The billiable of this TicketTimeEntriesQueryDTO.  # noqa: E501
        :type: bool
        """

        self._billiable = billiable

    @property
    def on_customer_site(self):
        """Gets the on_customer_site of this TicketTimeEntriesQueryDTO.  # noqa: E501


        :return: The on_customer_site of this TicketTimeEntriesQueryDTO.  # noqa: E501
        :rtype: bool
        """
        return self._on_customer_site

    @on_customer_site.setter
    def on_customer_site(self, on_customer_site):
        """Sets the on_customer_site of this TicketTimeEntriesQueryDTO.


        :param on_customer_site: The on_customer_site of this TicketTimeEntriesQueryDTO.  # noqa: E501
        :type: bool
        """

        self._on_customer_site = on_customer_site

    @property
    def description(self):
        """Gets the description of this TicketTimeEntriesQueryDTO.  # noqa: E501


        :return: The description of this TicketTimeEntriesQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TicketTimeEntriesQueryDTO.


        :param description: The description of this TicketTimeEntriesQueryDTO.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def technician_full_name(self):
        """Gets the technician_full_name of this TicketTimeEntriesQueryDTO.  # noqa: E501


        :return: The technician_full_name of this TicketTimeEntriesQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._technician_full_name

    @technician_full_name.setter
    def technician_full_name(self, technician_full_name):
        """Sets the technician_full_name of this TicketTimeEntriesQueryDTO.


        :param technician_full_name: The technician_full_name of this TicketTimeEntriesQueryDTO.  # noqa: E501
        :type: str
        """

        self._technician_full_name = technician_full_name

    @property
    def technician_email(self):
        """Gets the technician_email of this TicketTimeEntriesQueryDTO.  # noqa: E501


        :return: The technician_email of this TicketTimeEntriesQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._technician_email

    @technician_email.setter
    def technician_email(self, technician_email):
        """Sets the technician_email of this TicketTimeEntriesQueryDTO.


        :param technician_email: The technician_email of this TicketTimeEntriesQueryDTO.  # noqa: E501
        :type: str
        """

        self._technician_email = technician_email

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(TicketTimeEntriesQueryDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TicketTimeEntriesQueryDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TicketTimeEntriesQueryDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class TicketCommentQueryDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "_date": "datetime",
        "comment": "str",
        "end_user_id": "int",
        "technician_contact_id": "int",
        "email": "str",
        "first_name": "str",
        "last_name": "str",
        "is_internal": "bool",
    }

    attribute_map = {
        "_date": "Date",
        "comment": "Comment",
        "end_user_id": "EndUserID",
        "technician_contact_id": "TechnicianContactID",
        "email": "Email",
        "first_name": "FirstName",
        "last_name": "LastName",
        "is_internal": "IsInternal",
    }

    def __init__(
        self,
        _date=None,
        comment=None,
        end_user_id=None,
        technician_contact_id=None,
        email=None,
        first_name=None,
        last_name=None,
        is_internal=None,
        _configuration=None,
    ):  # noqa: E501
        """TicketCommentQueryDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self.__date = None
        self._comment = None
        self._end_user_id = None
        self._technician_contact_id = None
        self._email = None
        self._first_name = None
        self._last_name = None
        self._is_internal = None
        self.discriminator = None

        if _date is not None:
            self._date = _date
        if comment is not None:
            self.comment = comment
        if end_user_id is not None:
            self.end_user_id = end_user_id
        if technician_contact_id is not None:
            self.technician_contact_id = technician_contact_id
        if email is not None:
            self.email = email
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if is_internal is not None:
            self.is_internal = is_internal

    @property
    def _date(self):
        """Gets the _date of this TicketCommentQueryDTO.  # noqa: E501


        :return: The _date of this TicketCommentQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self.__date

    @_date.setter
    def _date(self, _date):
        """Sets the _date of this TicketCommentQueryDTO.


        :param _date: The _date of this TicketCommentQueryDTO.  # noqa: E501
        :type: datetime
        """

        self.__date = _date

    @property
    def comment(self):
        """Gets the comment of this TicketCommentQueryDTO.  # noqa: E501


        :return: The comment of this TicketCommentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this TicketCommentQueryDTO.


        :param comment: The comment of this TicketCommentQueryDTO.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def end_user_id(self):
        """Gets the end_user_id of this TicketCommentQueryDTO.  # noqa: E501


        :return: The end_user_id of this TicketCommentQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._end_user_id

    @end_user_id.setter
    def end_user_id(self, end_user_id):
        """Sets the end_user_id of this TicketCommentQueryDTO.


        :param end_user_id: The end_user_id of this TicketCommentQueryDTO.  # noqa: E501
        :type: int
        """

        self._end_user_id = end_user_id

    @property
    def technician_contact_id(self):
        """Gets the technician_contact_id of this TicketCommentQueryDTO.  # noqa: E501


        :return: The technician_contact_id of this TicketCommentQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._technician_contact_id

    @technician_contact_id.setter
    def technician_contact_id(self, technician_contact_id):
        """Sets the technician_contact_id of this TicketCommentQueryDTO.


        :param technician_contact_id: The technician_contact_id of this TicketCommentQueryDTO.  # noqa: E501
        :type: int
        """

        self._technician_contact_id = technician_contact_id

    @property
    def email(self):
        """Gets the email of this TicketCommentQueryDTO.  # noqa: E501


        :return: The email of this TicketCommentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this TicketCommentQueryDTO.


        :param email: The email of this TicketCommentQueryDTO.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def first_name(self):
        """Gets the first_name of this TicketCommentQueryDTO.  # noqa: E501


        :return: The first_name of this TicketCommentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this TicketCommentQueryDTO.


        :param first_name: The first_name of this TicketCommentQueryDTO.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this TicketCommentQueryDTO.  # noqa: E501


        :return: The last_name of this TicketCommentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this TicketCommentQueryDTO.


        :param last_name: The last_name of this TicketCommentQueryDTO.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def is_internal(self):
        """Gets the is_internal of this TicketCommentQueryDTO.  # noqa: E501


        :return: The is_internal of this TicketCommentQueryDTO.  # noqa: E501
        :rtype: bool
        """
        return self._is_internal

    @is_internal.setter
    def is_internal(self, is_internal):
        """Sets the is_internal of this TicketCommentQueryDTO.


        :param is_internal: The is_internal of this TicketCommentQueryDTO.  # noqa: E501
        :type: bool
        """

        self._is_internal = is_internal

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(TicketCommentQueryDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TicketCommentQueryDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TicketCommentQueryDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from atera_client.api_client import ApiClient


class ContractsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def contracts_contract_query_dto(self, contract_id, **kwargs):  # noqa: E501
        """Find specified contract  # noqa: E501

        Returns a specified contract. Requires the contract ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.contracts_contract_query_dto(contract_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int contract_id: Required. System contract ID (required)
        :return: ContractQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.contracts_contract_query_dto_with_http_info(contract_id, **kwargs)  # noqa: E501
        else:
            (data) = self.contracts_contract_query_dto_with_http_info(contract_id, **kwargs)  # noqa: E501
            return data

    def contracts_contract_query_dto_with_http_info(self, contract_id, **kwargs):  # noqa: E501
        """Find specified contract  # noqa: E501

        Returns a specified contract. Requires the contract ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.contracts_contract_query_dto_with_http_info(contract_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int contract_id: Required. System contract ID (required)
        :return: ContractQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["contract_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method contracts_contract_query_dto" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'contract_id' is set
        if self.api_client.client_side_validation and (
            "contract_id" not in params or params["contract_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `contract_id` when calling `contracts_contract_query_dto`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "contract_id" in params:
            path_params["contractId"] = params["contract_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/contracts/{contractId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ContractQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def contracts_get(self, **kwargs):  # noqa: E501
        """Find contracts  # noqa: E501

        Returns a list of contracts.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.contracts_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Optional - Page index, based on items per page (default is 1)
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :return: APIResultWrapperContractQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.contracts_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.contracts_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def contracts_get_with_http_info(self, **kwargs):  # noqa: E501
        """Find contracts  # noqa: E501

        Returns a list of contracts.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.contracts_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Optional - Page index, based on items per page (default is 1)
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :return: APIResultWrapperContractQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["page", "items_in_page"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method contracts_get" % key)
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "page" in params:
            query_params.append(("page", params["page"]))  # noqa: E501
        if "items_in_page" in params:
            query_params.append(("itemsInPage", params["items_in_page"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/contracts",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="APIResultWrapperContractQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def contracts_get_by_customer(self, customer_id, **kwargs):  # noqa: E501
        """Find contracts for specified customer  # noqa: E501

        Returns a list of contracts. Requires the customer ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.contracts_get_by_customer(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: Required - System customer ID (required)
        :param int page: Optional - Page index, based on items per page (default is 1)
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :return: APIResultWrapperContractQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.contracts_get_by_customer_with_http_info(customer_id, **kwargs)  # noqa: E501
        else:
            (data) = self.contracts_get_by_customer_with_http_info(customer_id, **kwargs)  # noqa: E501
            return data

    def contracts_get_by_customer_with_http_info(self, customer_id, **kwargs):  # noqa: E501
        """Find contracts for specified customer  # noqa: E501

        Returns a list of contracts. Requires the customer ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.contracts_get_by_customer_with_http_info(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: Required - System customer ID (required)
        :param int page: Optional - Page index, based on items per page (default is 1)
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :return: APIResultWrapperContractQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["customer_id", "page", "items_in_page"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method contracts_get_by_customer" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'customer_id' is set
        if self.api_client.client_side_validation and (
            "customer_id" not in params or params["customer_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `customer_id` when calling `contracts_get_by_customer`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "customer_id" in params:
            path_params["customerId"] = params["customer_id"]  # noqa: E501

        query_params = []
        if "page" in params:
            query_params.append(("page", params["page"]))  # noqa: E501
        if "items_in_page" in params:
            query_params.append(("itemsInPage", params["items_in_page"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/contracts/customer/{customerId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="APIResultWrapperContractQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from atera_client.api_client import ApiClient


class CustomerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def customer_delete(self, customer_id, **kwargs):  # noqa: E501
        """Delete specified customer  # noqa: E501

        Deletes a specified customer. Requires the customer ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.customer_delete(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: Required (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.customer_delete_with_http_info(customer_id, **kwargs)  # noqa: E501
        else:
            (data) = self.customer_delete_with_http_info(customer_id, **kwargs)  # noqa: E501
            return data

    def customer_delete_with_http_info(self, customer_id, **kwargs):  # noqa: E501
        """Delete specified customer  # noqa: E501

        Deletes a specified customer. Requires the customer ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.customer_delete_with_http_info(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: Required (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["customer_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method customer_delete" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'customer_id' is set
        if self.api_client.client_side_validation and (
            "customer_id" not in params or params["customer_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `customer_id` when calling `customer_delete`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "customer_id" in params:
            path_params["customerId"] = params["customer_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/customers/{customerId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def customer_get(self, **kwargs):  # noqa: E501
        """Find Customers  # noqa: E501

        Returns a list of customers.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.customer_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Optional - Page index, based on items per page (default is 1)
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :return: APIResultWrapperCustomerQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.customer_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.customer_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def customer_get_with_http_info(self, **kwargs):  # noqa: E501
        """Find Customers  # noqa: E501

        Returns a list of customers.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.customer_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Optional - Page index, based on items per page (default is 1)
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :return: APIResultWrapperCustomerQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["page", "items_in_page"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method customer_get" % key)
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "page" in params:
            query_params.append(("page", params["page"]))  # noqa: E501
        if "items_in_page" in params:
            query_params.append(("itemsInPage", params["items_in_page"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/customers",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="APIResultWrapperCustomerQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def customer_get_0(self, customer_id, **kwargs):  # noqa: E501
        """Find specified customer  # noqa: E501

        Returns a specified customer. Requires the customer ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.customer_get_0(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: Required (required)
        :return: CustomerQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.customer_get_0_with_http_info(customer_id, **kwargs)  # noqa: E501
        else:
            (data) = self.customer_get_0_with_http_info(customer_id, **kwargs)  # noqa: E501
            return data

    def customer_get_0_with_http_info(self, customer_id, **kwargs):  # noqa: E501
        """Find specified customer  # noqa: E501

        Returns a specified customer. Requires the customer ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.customer_get_0_with_http_info(customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: Required (required)
        :return: CustomerQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["customer_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method customer_get_0" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'customer_id' is set
        if self.api_client.client_side_validation and (
            "customer_id" not in params or params["customer_id"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `customer_id` when calling `customer_get_0`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "customer_id" in params:
            path_params["customerId"] = params["customer_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/customers/{customerId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CustomerQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def customer_post(self, customer, **kwargs):  # noqa: E501
        """Create Customer  # noqa: E501

        Creates a new customer. Requires the customer name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.customer_post(customer, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateCustomerDTO customer: Required (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.customer_post_with_http_info(customer, **kwargs)  # noqa: E501
        else:
            (data) = self.customer_post_with_http_info(customer, **kwargs)  # noqa: E501
            return data

    def customer_post_with_http_info(self, customer, **kwargs):  # noqa: E501
        """Create Customer  # noqa: E501

        Creates a new customer. Requires the customer name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.customer_post_with_http_info(customer, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateCustomerDTO customer: Required (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["customer"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method customer_post" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'customer' is set
        if self.api_client.client_side_validation and (
            "customer" not in params or params["customer"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `customer` when calling `customer_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "customer" in params:
            body_params = params["customer"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/customers",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Result",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def customer_post_0(self, folder, **kwargs):  # noqa: E501
        """Create Customer Folder  # noqa: E501

        Requires the folder name and customer ID.              Threshold profile ID is optional; if not included, the folder will inherit the threshold profile applied to the customer, if applicable.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.customer_post_0(folder, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateCustomerFolderDTO folder: Required (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.customer_post_0_with_http_info(folder, **kwargs)  # noqa: E501
        else:
            (data) = self.customer_post_0_with_http_info(folder, **kwargs)  # noqa: E501
            return data

    def customer_post_0_with_http_info(self, folder, **kwargs):  # noqa: E501
        """Create Customer Folder  # noqa: E501

        Requires the folder name and customer ID.              Threshold profile ID is optional; if not included, the folder will inherit the threshold profile applied to the customer, if applicable.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.customer_post_0_with_http_info(folder, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateCustomerFolderDTO folder: Required (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["folder"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method customer_post_0" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'folder' is set
        if self.api_client.client_side_validation and (
            "folder" not in params or params["folder"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `folder` when calling `customer_post_0`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "folder" in params:
            body_params = params["folder"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/customers/folders",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Result",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def customer_post_1(self, attachment, **kwargs):  # noqa: E501
        """Create Customer Attachment  # noqa: E501

        Requires the customer ID and attachment name, including the file extension. Requires attachment to be represented in Base64 encoding.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.customer_post_1(attachment, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateCustomerAttachmentDTO attachment: Required (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.customer_post_1_with_http_info(attachment, **kwargs)  # noqa: E501
        else:
            (data) = self.customer_post_1_with_http_info(attachment, **kwargs)  # noqa: E501
            return data

    def customer_post_1_with_http_info(self, attachment, **kwargs):  # noqa: E501
        """Create Customer Attachment  # noqa: E501

        Requires the customer ID and attachment name, including the file extension. Requires attachment to be represented in Base64 encoding.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.customer_post_1_with_http_info(attachment, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateCustomerAttachmentDTO attachment: Required (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["attachment"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method customer_post_1" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'attachment' is set
        if self.api_client.client_side_validation and (
            "attachment" not in params or params["attachment"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `attachment` when calling `customer_post_1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "attachment" in params:
            body_params = params["attachment"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/customers/attachments",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Result",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def customer_put(self, customer_id, customer, **kwargs):  # noqa: E501
        """Update specified customer  # noqa: E501

        Updates an existing customer. Requires the customer ID.              <br /><br />               The following fields are editable:              <br /><br />               Customer Name (CustomerName)              <br />              Business Number (BusinessNumber)              <br />               Domain (Domain)              <br />              Address (Address)              <br />              City (City)              <br />              State (State)              <br />              Country (Country)              <br />              Phone (Phone)              <br />              Fax (Fax)              <br />              Notes (Notes)              <br />              Links (Links)              <br />              Longitude (Longitude)              <br />              Latitude (Latitude)              <br />              Zip Code (ZipCodeStr)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.customer_put(customer_id, customer, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: Required (required)
        :param UpdateCustomerDTO customer: Required (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.customer_put_with_http_info(customer_id, customer, **kwargs)  # noqa: E501
        else:
            (data) = self.customer_put_with_http_info(customer_id, customer, **kwargs)  # noqa: E501
            return data

    def customer_put_with_http_info(self, customer_id, customer, **kwargs):  # noqa: E501
        """Update specified customer  # noqa: E501

        Updates an existing customer. Requires the customer ID.              <br /><br />               The following fields are editable:              <br /><br />               Customer Name (CustomerName)              <br />              Business Number (BusinessNumber)              <br />               Domain (Domain)              <br />              Address (Address)              <br />              City (City)              <br />              State (State)              <br />              Country (Country)              <br />              Phone (Phone)              <br />              Fax (Fax)              <br />              Notes (Notes)              <br />              Links (Links)              <br />              Longitude (Longitude)              <br />              Latitude (Latitude)              <br />              Zip Code (ZipCodeStr)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.customer_put_with_http_info(customer_id, customer, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: Required (required)
        :param UpdateCustomerDTO customer: Required (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["customer_id", "customer"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method customer_put" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'customer_id' is set
        if self.api_client.client_side_validation and (
            "customer_id" not in params or params["customer_id"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `customer_id` when calling `customer_put`")  # noqa: E501
        # verify the required parameter 'customer' is set
        if self.api_client.client_side_validation and (
            "customer" not in params or params["customer"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `customer` when calling `customer_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "customer_id" in params:
            path_params["customerId"] = params["customer_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "customer" in params:
            body_params = params["customer"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/customers/{customerId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Result",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def customer_put_0(self, customer_id, customer, **kwargs):  # noqa: E501
        """Update specified customer  # noqa: E501

        Updates an existing customer. Requires the customer ID.              <br /><br />               The following fields are editable:              <br /><br />               Customer Name (CustomerName)              <br />              Business Number (BusinessNumber)              <br />               Domain (Domain)              <br />              Address (Address)              <br />              City (City)              <br />              State (State)              <br />              Country (Country)              <br />              Phone (Phone)              <br />              Fax (Fax)              <br />              Notes (Notes)              <br />              Links (Links)              <br />              Longitude (Longitude)              <br />              Latitude (Latitude)              <br />              Zip Code (ZipCodeStr)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.customer_put_0(customer_id, customer, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: Required (required)
        :param UpdateCustomerDTO customer: Required (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.customer_put_0_with_http_info(customer_id, customer, **kwargs)  # noqa: E501
        else:
            (data) = self.customer_put_0_with_http_info(customer_id, customer, **kwargs)  # noqa: E501
            return data

    def customer_put_0_with_http_info(self, customer_id, customer, **kwargs):  # noqa: E501
        """Update specified customer  # noqa: E501

        Updates an existing customer. Requires the customer ID.              <br /><br />               The following fields are editable:              <br /><br />               Customer Name (CustomerName)              <br />              Business Number (BusinessNumber)              <br />               Domain (Domain)              <br />              Address (Address)              <br />              City (City)              <br />              State (State)              <br />              Country (Country)              <br />              Phone (Phone)              <br />              Fax (Fax)              <br />              Notes (Notes)              <br />              Links (Links)              <br />              Longitude (Longitude)              <br />              Latitude (Latitude)              <br />              Zip Code (ZipCodeStr)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.customer_put_0_with_http_info(customer_id, customer, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int customer_id: Required (required)
        :param UpdateCustomerDTO customer: Required (required)
        :return: Result
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["customer_id", "customer"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method customer_put_0" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'customer_id' is set
        if self.api_client.client_side_validation and (
            "customer_id" not in params or params["customer_id"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `customer_id` when calling `customer_put_0`")  # noqa: E501
        # verify the required parameter 'customer' is set
        if self.api_client.client_side_validation and (
            "customer" not in params or params["customer"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `customer` when calling `customer_put_0`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "customer_id" in params:
            path_params["customerId"] = params["customer_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "customer" in params:
            body_params = params["customer"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/customers/{customerId}",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Result",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class CreateCustomerAttachmentDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"customer_id": "int", "name": "str", "content_based64": "str"}

    attribute_map = {"customer_id": "CustomerId", "name": "Name", "content_based64": "ContentBased64"}

    def __init__(self, customer_id=None, name=None, content_based64=None, _configuration=None):  # noqa: E501
        """CreateCustomerAttachmentDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._customer_id = None
        self._name = None
        self._content_based64 = None
        self.discriminator = None

        self.customer_id = customer_id
        self.name = name
        self.content_based64 = content_based64

    @property
    def customer_id(self):
        """Gets the customer_id of this CreateCustomerAttachmentDTO.  # noqa: E501


        :return: The customer_id of this CreateCustomerAttachmentDTO.  # noqa: E501
        :rtype: int
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this CreateCustomerAttachmentDTO.


        :param customer_id: The customer_id of this CreateCustomerAttachmentDTO.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and customer_id is None:
            raise ValueError("Invalid value for `customer_id`, must not be `None`")  # noqa: E501

        self._customer_id = customer_id

    @property
    def name(self):
        """Gets the name of this CreateCustomerAttachmentDTO.  # noqa: E501


        :return: The name of this CreateCustomerAttachmentDTO.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateCustomerAttachmentDTO.


        :param name: The name of this CreateCustomerAttachmentDTO.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def content_based64(self):
        """Gets the content_based64 of this CreateCustomerAttachmentDTO.  # noqa: E501


        :return: The content_based64 of this CreateCustomerAttachmentDTO.  # noqa: E501
        :rtype: str
        """
        return self._content_based64

    @content_based64.setter
    def content_based64(self, content_based64):
        """Sets the content_based64 of this CreateCustomerAttachmentDTO.


        :param content_based64: The content_based64 of this CreateCustomerAttachmentDTO.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and content_based64 is None:
            raise ValueError("Invalid value for `content_based64`, must not be `None`")  # noqa: E501

        self._content_based64 = content_based64

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(CreateCustomerAttachmentDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateCustomerAttachmentDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateCustomerAttachmentDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class OnlineBackupContractQueryDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"rate_per_gb": "RateQueryDTO", "count_by": "str", "billing_period": "str"}

    attribute_map = {"rate_per_gb": "RatePerGB", "count_by": "CountBy", "billing_period": "BillingPeriod"}

    def __init__(self, rate_per_gb=None, count_by=None, billing_period=None, _configuration=None):  # noqa: E501
        """OnlineBackupContractQueryDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._rate_per_gb = None
        self._count_by = None
        self._billing_period = None
        self.discriminator = None

        if rate_per_gb is not None:
            self.rate_per_gb = rate_per_gb
        if count_by is not None:
            self.count_by = count_by
        if billing_period is not None:
            self.billing_period = billing_period

    @property
    def rate_per_gb(self):
        """Gets the rate_per_gb of this OnlineBackupContractQueryDTO.  # noqa: E501


        :return: The rate_per_gb of this OnlineBackupContractQueryDTO.  # noqa: E501
        :rtype: RateQueryDTO
        """
        return self._rate_per_gb

    @rate_per_gb.setter
    def rate_per_gb(self, rate_per_gb):
        """Sets the rate_per_gb of this OnlineBackupContractQueryDTO.


        :param rate_per_gb: The rate_per_gb of this OnlineBackupContractQueryDTO.  # noqa: E501
        :type: RateQueryDTO
        """

        self._rate_per_gb = rate_per_gb

    @property
    def count_by(self):
        """Gets the count_by of this OnlineBackupContractQueryDTO.  # noqa: E501


        :return: The count_by of this OnlineBackupContractQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._count_by

    @count_by.setter
    def count_by(self, count_by):
        """Sets the count_by of this OnlineBackupContractQueryDTO.


        :param count_by: The count_by of this OnlineBackupContractQueryDTO.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "PCAgents",
            "MacAgents",
            "ServerAgents",
            "OtherDevices",
            "AgentsOnly",
            "All",
            "PCsTotalGB",
            "ServersTotalGB",
            "TotalGB",
        ]  # noqa: E501
        if self._configuration.client_side_validation and count_by not in allowed_values:
            raise ValueError(
                "Invalid value for `count_by` ({0}), must be one of {1}".format(count_by, allowed_values)  # noqa: E501
            )

        self._count_by = count_by

    @property
    def billing_period(self):
        """Gets the billing_period of this OnlineBackupContractQueryDTO.  # noqa: E501


        :return: The billing_period of this OnlineBackupContractQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._billing_period

    @billing_period.setter
    def billing_period(self, billing_period):
        """Sets the billing_period of this OnlineBackupContractQueryDTO.


        :param billing_period: The billing_period of this OnlineBackupContractQueryDTO.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "EndOfContractDuration",
            "Weekly",
            "BiWeekly",
            "Monthly",
            "Quarterly",
            "TwiceAYear",
            "Yearly",
            "OnDemand",
        ]  # noqa: E501
        if self._configuration.client_side_validation and billing_period not in allowed_values:
            raise ValueError(
                "Invalid value for `billing_period` ({0}), must be one of {1}".format(  # noqa: E501
                    billing_period, allowed_values
                )
            )

        self._billing_period = billing_period

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(OnlineBackupContractQueryDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OnlineBackupContractQueryDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OnlineBackupContractQueryDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class UpdateCustomerDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "customer_name": "str",
        "business_number": "str",
        "domain": "str",
        "address": "str",
        "city": "str",
        "state": "str",
        "country": "str",
        "phone": "str",
        "fax": "str",
        "notes": "str",
        "links": "str",
        "longitude": "float",
        "latitude": "float",
        "zip_code_str": "str",
    }

    attribute_map = {
        "customer_name": "CustomerName",
        "business_number": "BusinessNumber",
        "domain": "Domain",
        "address": "Address",
        "city": "City",
        "state": "State",
        "country": "Country",
        "phone": "Phone",
        "fax": "Fax",
        "notes": "Notes",
        "links": "Links",
        "longitude": "Longitude",
        "latitude": "Latitude",
        "zip_code_str": "ZipCodeStr",
    }

    def __init__(
        self,
        customer_name=None,
        business_number=None,
        domain=None,
        address=None,
        city=None,
        state=None,
        country=None,
        phone=None,
        fax=None,
        notes=None,
        links=None,
        longitude=None,
        latitude=None,
        zip_code_str=None,
        _configuration=None,
    ):  # noqa: E501
        """UpdateCustomerDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._customer_name = None
        self._business_number = None
        self._domain = None
        self._address = None
        self._city = None
        self._state = None
        self._country = None
        self._phone = None
        self._fax = None
        self._notes = None
        self._links = None
        self._longitude = None
        self._latitude = None
        self._zip_code_str = None
        self.discriminator = None

        if customer_name is not None:
            self.customer_name = customer_name
        if business_number is not None:
            self.business_number = business_number
        if domain is not None:
            self.domain = domain
        if address is not None:
            self.address = address
        if city is not None:
            self.city = city
        if state is not None:
            self.state = state
        if country is not None:
            self.country = country
        if phone is not None:
            self.phone = phone
        if fax is not None:
            self.fax = fax
        if notes is not None:
            self.notes = notes
        if links is not None:
            self.links = links
        if longitude is not None:
            self.longitude = longitude
        if latitude is not None:
            self.latitude = latitude
        if zip_code_str is not None:
            self.zip_code_str = zip_code_str

    @property
    def customer_name(self):
        """Gets the customer_name of this UpdateCustomerDTO.  # noqa: E501


        :return: The customer_name of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._customer_name

    @customer_name.setter
    def customer_name(self, customer_name):
        """Sets the customer_name of this UpdateCustomerDTO.


        :param customer_name: The customer_name of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._customer_name = customer_name

    @property
    def business_number(self):
        """Gets the business_number of this UpdateCustomerDTO.  # noqa: E501


        :return: The business_number of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._business_number

    @business_number.setter
    def business_number(self, business_number):
        """Sets the business_number of this UpdateCustomerDTO.


        :param business_number: The business_number of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._business_number = business_number

    @property
    def domain(self):
        """Gets the domain of this UpdateCustomerDTO.  # noqa: E501


        :return: The domain of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this UpdateCustomerDTO.


        :param domain: The domain of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._domain = domain

    @property
    def address(self):
        """Gets the address of this UpdateCustomerDTO.  # noqa: E501


        :return: The address of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this UpdateCustomerDTO.


        :param address: The address of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def city(self):
        """Gets the city of this UpdateCustomerDTO.  # noqa: E501


        :return: The city of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this UpdateCustomerDTO.


        :param city: The city of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def state(self):
        """Gets the state of this UpdateCustomerDTO.  # noqa: E501


        :return: The state of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this UpdateCustomerDTO.


        :param state: The state of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def country(self):
        """Gets the country of this UpdateCustomerDTO.  # noqa: E501


        :return: The country of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this UpdateCustomerDTO.


        :param country: The country of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def phone(self):
        """Gets the phone of this UpdateCustomerDTO.  # noqa: E501


        :return: The phone of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this UpdateCustomerDTO.


        :param phone: The phone of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._phone = phone

    @property
    def fax(self):
        """Gets the fax of this UpdateCustomerDTO.  # noqa: E501


        :return: The fax of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._fax

    @fax.setter
    def fax(self, fax):
        """Sets the fax of this UpdateCustomerDTO.


        :param fax: The fax of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._fax = fax

    @property
    def notes(self):
        """Gets the notes of this UpdateCustomerDTO.  # noqa: E501


        :return: The notes of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """Sets the notes of this UpdateCustomerDTO.


        :param notes: The notes of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._notes = notes

    @property
    def links(self):
        """Gets the links of this UpdateCustomerDTO.  # noqa: E501


        :return: The links of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this UpdateCustomerDTO.


        :param links: The links of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._links = links

    @property
    def longitude(self):
        """Gets the longitude of this UpdateCustomerDTO.  # noqa: E501


        :return: The longitude of this UpdateCustomerDTO.  # noqa: E501
        :rtype: float
        """
        return self._longitude

    @longitude.setter
    def longitude(self, longitude):
        """Sets the longitude of this UpdateCustomerDTO.


        :param longitude: The longitude of this UpdateCustomerDTO.  # noqa: E501
        :type: float
        """

        self._longitude = longitude

    @property
    def latitude(self):
        """Gets the latitude of this UpdateCustomerDTO.  # noqa: E501


        :return: The latitude of this UpdateCustomerDTO.  # noqa: E501
        :rtype: float
        """
        return self._latitude

    @latitude.setter
    def latitude(self, latitude):
        """Sets the latitude of this UpdateCustomerDTO.


        :param latitude: The latitude of this UpdateCustomerDTO.  # noqa: E501
        :type: float
        """

        self._latitude = latitude

    @property
    def zip_code_str(self):
        """Gets the zip_code_str of this UpdateCustomerDTO.  # noqa: E501


        :return: The zip_code_str of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._zip_code_str

    @zip_code_str.setter
    def zip_code_str(self, zip_code_str):
        """Sets the zip_code_str of this UpdateCustomerDTO.


        :param zip_code_str: The zip_code_str of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._zip_code_str = zip_code_str

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UpdateCustomerDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateCustomerDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateCustomerDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class AgentQueryDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "machine_id": "str",
        "agent_id": "int",
        "device_guid": "str",
        "folder_id": "int",
        "customer_id": "int",
        "customer_name": "str",
        "agent_name": "str",
        "system_name": "str",
        "machine_name": "str",
        "domain_name": "str",
        "current_logged_users": "str",
        "computer_description": "str",
        "monitored": "bool",
        "last_patch_management_received": "datetime",
        "agent_version": "str",
        "favorite": "bool",
        "threshold_id": "int",
        "monitored_agent_id": "int",
        "created": "datetime",
        "modified": "datetime",
        "online": "bool",
        "reported_from_ip": "str",
        "app_view_url": "str",
        "motherboard": "str",
        "processor": "str",
        "memory": "int",
        "display": "str",
        "sound": "str",
        "processor_cores_count": "int",
        "system_drive": "str",
        "processor_clock": "str",
        "vendor": "str",
        "vendor_serial_number": "str",
        "vendor_brand_model": "str",
        "product_name": "str",
        "mac_addresses": "list[str]",
        "ip_addresses": "list[str]",
        "hardware_disks": "Object",
        "os": "str",
        "os_type": "str",
        "windows_serial_number": "str",
        "office": "str",
        "office_sp": "str",
        "office_oem": "bool",
        "office_serial_number": "str",
        "os_num": "float",
        "last_reboot_time": "datetime",
        "os_version": "str",
        "os_build": "str",
        "office_full_version": "str",
        "last_login_user": "str",
    }

    attribute_map = {
        "machine_id": "MachineID",
        "agent_id": "AgentID",
        "device_guid": "DeviceGuid",
        "folder_id": "FolderID",
        "customer_id": "CustomerID",
        "customer_name": "CustomerName",
        "agent_name": "AgentName",
        "system_name": "SystemName",
        "machine_name": "MachineName",
        "domain_name": "DomainName",
        "current_logged_users": "CurrentLoggedUsers",
        "computer_description": "ComputerDescription",
        "monitored": "Monitored",
        "last_patch_management_received": "LastPatchManagementReceived",
        "agent_version": "AgentVersion",
        "favorite": "Favorite",
        "threshold_id": "ThresholdID",
        "monitored_agent_id": "MonitoredAgentID",
        "created": "Created",
        "modified": "Modified",
        "online": "Online",
        "reported_from_ip": "ReportedFromIP",
        "app_view_url": "AppViewUrl",
        "motherboard": "Motherboard",
        "processor": "Processor",
        "memory": "Memory",
        "display": "Display",
        "sound": "Sound",
        "processor_cores_count": "ProcessorCoresCount",
        "system_drive": "SystemDrive",
        "processor_clock": "ProcessorClock",
        "vendor": "Vendor",
        "vendor_serial_number": "VendorSerialNumber",
        "vendor_brand_model": "VendorBrandModel",
        "product_name": "ProductName",
        "mac_addresses": "MacAddresses",
        "ip_addresses": "IpAddresses",
        "hardware_disks": "HardwareDisks",
        "os": "OS",
        "os_type": "OSType",
        "windows_serial_number": "WindowsSerialNumber",
        "office": "Office",
        "office_sp": "OfficeSP",
        "office_oem": "OfficeOEM",
        "office_serial_number": "OfficeSerialNumber",
        "os_num": "OSNum",
        "last_reboot_time": "LastRebootTime",
        "os_version": "OSVersion",
        "os_build": "OSBuild",
        "office_full_version": "OfficeFullVersion",
        "last_login_user": "LastLoginUser",
    }

    def __init__(
        self,
        machine_id=None,
        agent_id=None,
        device_guid=None,
        folder_id=None,
        customer_id=None,
        customer_name=None,
        agent_name=None,
        system_name=None,
        machine_name=None,
        domain_name=None,
        current_logged_users=None,
        computer_description=None,
        monitored=None,
        last_patch_management_received=None,
        agent_version=None,
        favorite=None,
        threshold_id=None,
        monitored_agent_id=None,
        created=None,
        modified=None,
        online=None,
        reported_from_ip=None,
        app_view_url=None,
        motherboard=None,
        processor=None,
        memory=None,
        display=None,
        sound=None,
        processor_cores_count=None,
        system_drive=None,
        processor_clock=None,
        vendor=None,
        vendor_serial_number=None,
        vendor_brand_model=None,
        product_name=None,
        mac_addresses=None,
        ip_addresses=None,
        hardware_disks=None,
        os=None,
        os_type=None,
        windows_serial_number=None,
        office=None,
        office_sp=None,
        office_oem=None,
        office_serial_number=None,
        os_num=None,
        last_reboot_time=None,
        os_version=None,
        os_build=None,
        office_full_version=None,
        last_login_user=None,
        _configuration=None,
    ):  # noqa: E501
        """AgentQueryDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._machine_id = None
        self._agent_id = None
        self._device_guid = None
        self._folder_id = None
        self._customer_id = None
        self._customer_name = None
        self._agent_name = None
        self._system_name = None
        self._machine_name = None
        self._domain_name = None
        self._current_logged_users = None
        self._computer_description = None
        self._monitored = None
        self._last_patch_management_received = None
        self._agent_version = None
        self._favorite = None
        self._threshold_id = None
        self._monitored_agent_id = None
        self._created = None
        self._modified = None
        self._online = None
        self._reported_from_ip = None
        self._app_view_url = None
        self._motherboard = None
        self._processor = None
        self._memory = None
        self._display = None
        self._sound = None
        self._processor_cores_count = None
        self._system_drive = None
        self._processor_clock = None
        self._vendor = None
        self._vendor_serial_number = None
        self._vendor_brand_model = None
        self._product_name = None
        self._mac_addresses = None
        self._ip_addresses = None
        self._hardware_disks = None
        self._os = None
        self._os_type = None
        self._windows_serial_number = None
        self._office = None
        self._office_sp = None
        self._office_oem = None
        self._office_serial_number = None
        self._os_num = None
        self._last_reboot_time = None
        self._os_version = None
        self._os_build = None
        self._office_full_version = None
        self._last_login_user = None
        self.discriminator = None

        if machine_id is not None:
            self.machine_id = machine_id
        if agent_id is not None:
            self.agent_id = agent_id
        if device_guid is not None:
            self.device_guid = device_guid
        if folder_id is not None:
            self.folder_id = folder_id
        if customer_id is not None:
            self.customer_id = customer_id
        if customer_name is not None:
            self.customer_name = customer_name
        if agent_name is not None:
            self.agent_name = agent_name
        if system_name is not None:
            self.system_name = system_name
        if machine_name is not None:
            self.machine_name = machine_name
        if domain_name is not None:
            self.domain_name = domain_name
        if current_logged_users is not None:
            self.current_logged_users = current_logged_users
        if computer_description is not None:
            self.computer_description = computer_description
        if monitored is not None:
            self.monitored = monitored
        if last_patch_management_received is not None:
            self.last_patch_management_received = last_patch_management_received
        if agent_version is not None:
            self.agent_version = agent_version
        if favorite is not None:
            self.favorite = favorite
        if threshold_id is not None:
            self.threshold_id = threshold_id
        if monitored_agent_id is not None:
            self.monitored_agent_id = monitored_agent_id
        if created is not None:
            self.created = created
        if modified is not None:
            self.modified = modified
        if online is not None:
            self.online = online
        if reported_from_ip is not None:
            self.reported_from_ip = reported_from_ip
        if app_view_url is not None:
            self.app_view_url = app_view_url
        if motherboard is not None:
            self.motherboard = motherboard
        if processor is not None:
            self.processor = processor
        if memory is not None:
            self.memory = memory
        if display is not None:
            self.display = display
        if sound is not None:
            self.sound = sound
        if processor_cores_count is not None:
            self.processor_cores_count = processor_cores_count
        if system_drive is not None:
            self.system_drive = system_drive
        if processor_clock is not None:
            self.processor_clock = processor_clock
        if vendor is not None:
            self.vendor = vendor
        if vendor_serial_number is not None:
            self.vendor_serial_number = vendor_serial_number
        if vendor_brand_model is not None:
            self.vendor_brand_model = vendor_brand_model
        if product_name is not None:
            self.product_name = product_name
        if mac_addresses is not None:
            self.mac_addresses = mac_addresses
        if ip_addresses is not None:
            self.ip_addresses = ip_addresses
        if hardware_disks is not None:
            self.hardware_disks = hardware_disks
        if os is not None:
            self.os = os
        if os_type is not None:
            self.os_type = os_type
        if windows_serial_number is not None:
            self.windows_serial_number = windows_serial_number
        if office is not None:
            self.office = office
        if office_sp is not None:
            self.office_sp = office_sp
        if office_oem is not None:
            self.office_oem = office_oem
        if office_serial_number is not None:
            self.office_serial_number = office_serial_number
        if os_num is not None:
            self.os_num = os_num
        if last_reboot_time is not None:
            self.last_reboot_time = last_reboot_time
        if os_version is not None:
            self.os_version = os_version
        if os_build is not None:
            self.os_build = os_build
        if office_full_version is not None:
            self.office_full_version = office_full_version
        if last_login_user is not None:
            self.last_login_user = last_login_user

    @property
    def machine_id(self):
        """Gets the machine_id of this AgentQueryDTO.  # noqa: E501


        :return: The machine_id of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._machine_id

    @machine_id.setter
    def machine_id(self, machine_id):
        """Sets the machine_id of this AgentQueryDTO.


        :param machine_id: The machine_id of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._machine_id = machine_id

    @property
    def agent_id(self):
        """Gets the agent_id of this AgentQueryDTO.  # noqa: E501


        :return: The agent_id of this AgentQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._agent_id

    @agent_id.setter
    def agent_id(self, agent_id):
        """Sets the agent_id of this AgentQueryDTO.


        :param agent_id: The agent_id of this AgentQueryDTO.  # noqa: E501
        :type: int
        """

        self._agent_id = agent_id

    @property
    def device_guid(self):
        """Gets the device_guid of this AgentQueryDTO.  # noqa: E501


        :return: The device_guid of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._device_guid

    @device_guid.setter
    def device_guid(self, device_guid):
        """Sets the device_guid of this AgentQueryDTO.


        :param device_guid: The device_guid of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._device_guid = device_guid

    @property
    def folder_id(self):
        """Gets the folder_id of this AgentQueryDTO.  # noqa: E501


        :return: The folder_id of this AgentQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._folder_id

    @folder_id.setter
    def folder_id(self, folder_id):
        """Sets the folder_id of this AgentQueryDTO.


        :param folder_id: The folder_id of this AgentQueryDTO.  # noqa: E501
        :type: int
        """

        self._folder_id = folder_id

    @property
    def customer_id(self):
        """Gets the customer_id of this AgentQueryDTO.  # noqa: E501


        :return: The customer_id of this AgentQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this AgentQueryDTO.


        :param customer_id: The customer_id of this AgentQueryDTO.  # noqa: E501
        :type: int
        """

        self._customer_id = customer_id

    @property
    def customer_name(self):
        """Gets the customer_name of this AgentQueryDTO.  # noqa: E501


        :return: The customer_name of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._customer_name

    @customer_name.setter
    def customer_name(self, customer_name):
        """Sets the customer_name of this AgentQueryDTO.


        :param customer_name: The customer_name of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._customer_name = customer_name

    @property
    def agent_name(self):
        """Gets the agent_name of this AgentQueryDTO.  # noqa: E501


        :return: The agent_name of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._agent_name

    @agent_name.setter
    def agent_name(self, agent_name):
        """Sets the agent_name of this AgentQueryDTO.


        :param agent_name: The agent_name of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._agent_name = agent_name

    @property
    def system_name(self):
        """Gets the system_name of this AgentQueryDTO.  # noqa: E501


        :return: The system_name of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._system_name

    @system_name.setter
    def system_name(self, system_name):
        """Sets the system_name of this AgentQueryDTO.


        :param system_name: The system_name of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._system_name = system_name

    @property
    def machine_name(self):
        """Gets the machine_name of this AgentQueryDTO.  # noqa: E501


        :return: The machine_name of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._machine_name

    @machine_name.setter
    def machine_name(self, machine_name):
        """Sets the machine_name of this AgentQueryDTO.


        :param machine_name: The machine_name of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._machine_name = machine_name

    @property
    def domain_name(self):
        """Gets the domain_name of this AgentQueryDTO.  # noqa: E501


        :return: The domain_name of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._domain_name

    @domain_name.setter
    def domain_name(self, domain_name):
        """Sets the domain_name of this AgentQueryDTO.


        :param domain_name: The domain_name of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._domain_name = domain_name

    @property
    def current_logged_users(self):
        """Gets the current_logged_users of this AgentQueryDTO.  # noqa: E501


        :return: The current_logged_users of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._current_logged_users

    @current_logged_users.setter
    def current_logged_users(self, current_logged_users):
        """Sets the current_logged_users of this AgentQueryDTO.


        :param current_logged_users: The current_logged_users of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._current_logged_users = current_logged_users

    @property
    def computer_description(self):
        """Gets the computer_description of this AgentQueryDTO.  # noqa: E501


        :return: The computer_description of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._computer_description

    @computer_description.setter
    def computer_description(self, computer_description):
        """Sets the computer_description of this AgentQueryDTO.


        :param computer_description: The computer_description of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._computer_description = computer_description

    @property
    def monitored(self):
        """Gets the monitored of this AgentQueryDTO.  # noqa: E501


        :return: The monitored of this AgentQueryDTO.  # noqa: E501
        :rtype: bool
        """
        return self._monitored

    @monitored.setter
    def monitored(self, monitored):
        """Sets the monitored of this AgentQueryDTO.


        :param monitored: The monitored of this AgentQueryDTO.  # noqa: E501
        :type: bool
        """

        self._monitored = monitored

    @property
    def last_patch_management_received(self):
        """Gets the last_patch_management_received of this AgentQueryDTO.  # noqa: E501

        Deprecated  # noqa: E501

        :return: The last_patch_management_received of this AgentQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._last_patch_management_received

    @last_patch_management_received.setter
    def last_patch_management_received(self, last_patch_management_received):
        """Sets the last_patch_management_received of this AgentQueryDTO.

        Deprecated  # noqa: E501

        :param last_patch_management_received: The last_patch_management_received of this AgentQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._last_patch_management_received = last_patch_management_received

    @property
    def agent_version(self):
        """Gets the agent_version of this AgentQueryDTO.  # noqa: E501


        :return: The agent_version of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._agent_version

    @agent_version.setter
    def agent_version(self, agent_version):
        """Sets the agent_version of this AgentQueryDTO.


        :param agent_version: The agent_version of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._agent_version = agent_version

    @property
    def favorite(self):
        """Gets the favorite of this AgentQueryDTO.  # noqa: E501


        :return: The favorite of this AgentQueryDTO.  # noqa: E501
        :rtype: bool
        """
        return self._favorite

    @favorite.setter
    def favorite(self, favorite):
        """Sets the favorite of this AgentQueryDTO.


        :param favorite: The favorite of this AgentQueryDTO.  # noqa: E501
        :type: bool
        """

        self._favorite = favorite

    @property
    def threshold_id(self):
        """Gets the threshold_id of this AgentQueryDTO.  # noqa: E501


        :return: The threshold_id of this AgentQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._threshold_id

    @threshold_id.setter
    def threshold_id(self, threshold_id):
        """Sets the threshold_id of this AgentQueryDTO.


        :param threshold_id: The threshold_id of this AgentQueryDTO.  # noqa: E501
        :type: int
        """

        self._threshold_id = threshold_id

    @property
    def monitored_agent_id(self):
        """Gets the monitored_agent_id of this AgentQueryDTO.  # noqa: E501


        :return: The monitored_agent_id of this AgentQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._monitored_agent_id

    @monitored_agent_id.setter
    def monitored_agent_id(self, monitored_agent_id):
        """Sets the monitored_agent_id of this AgentQueryDTO.


        :param monitored_agent_id: The monitored_agent_id of this AgentQueryDTO.  # noqa: E501
        :type: int
        """

        self._monitored_agent_id = monitored_agent_id

    @property
    def created(self):
        """Gets the created of this AgentQueryDTO.  # noqa: E501


        :return: The created of this AgentQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this AgentQueryDTO.


        :param created: The created of this AgentQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def modified(self):
        """Gets the modified of this AgentQueryDTO.  # noqa: E501


        :return: The modified of this AgentQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this AgentQueryDTO.


        :param modified: The modified of this AgentQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    @property
    def online(self):
        """Gets the online of this AgentQueryDTO.  # noqa: E501


        :return: The online of this AgentQueryDTO.  # noqa: E501
        :rtype: bool
        """
        return self._online

    @online.setter
    def online(self, online):
        """Sets the online of this AgentQueryDTO.


        :param online: The online of this AgentQueryDTO.  # noqa: E501
        :type: bool
        """

        self._online = online

    @property
    def reported_from_ip(self):
        """Gets the reported_from_ip of this AgentQueryDTO.  # noqa: E501


        :return: The reported_from_ip of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._reported_from_ip

    @reported_from_ip.setter
    def reported_from_ip(self, reported_from_ip):
        """Sets the reported_from_ip of this AgentQueryDTO.


        :param reported_from_ip: The reported_from_ip of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._reported_from_ip = reported_from_ip

    @property
    def app_view_url(self):
        """Gets the app_view_url of this AgentQueryDTO.  # noqa: E501


        :return: The app_view_url of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._app_view_url

    @app_view_url.setter
    def app_view_url(self, app_view_url):
        """Sets the app_view_url of this AgentQueryDTO.


        :param app_view_url: The app_view_url of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._app_view_url = app_view_url

    @property
    def motherboard(self):
        """Gets the motherboard of this AgentQueryDTO.  # noqa: E501


        :return: The motherboard of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._motherboard

    @motherboard.setter
    def motherboard(self, motherboard):
        """Sets the motherboard of this AgentQueryDTO.


        :param motherboard: The motherboard of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._motherboard = motherboard

    @property
    def processor(self):
        """Gets the processor of this AgentQueryDTO.  # noqa: E501


        :return: The processor of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._processor

    @processor.setter
    def processor(self, processor):
        """Sets the processor of this AgentQueryDTO.


        :param processor: The processor of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._processor = processor

    @property
    def memory(self):
        """Gets the memory of this AgentQueryDTO.  # noqa: E501


        :return: The memory of this AgentQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._memory

    @memory.setter
    def memory(self, memory):
        """Sets the memory of this AgentQueryDTO.


        :param memory: The memory of this AgentQueryDTO.  # noqa: E501
        :type: int
        """

        self._memory = memory

    @property
    def display(self):
        """Gets the display of this AgentQueryDTO.  # noqa: E501


        :return: The display of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._display

    @display.setter
    def display(self, display):
        """Sets the display of this AgentQueryDTO.


        :param display: The display of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._display = display

    @property
    def sound(self):
        """Gets the sound of this AgentQueryDTO.  # noqa: E501


        :return: The sound of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._sound

    @sound.setter
    def sound(self, sound):
        """Sets the sound of this AgentQueryDTO.


        :param sound: The sound of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._sound = sound

    @property
    def processor_cores_count(self):
        """Gets the processor_cores_count of this AgentQueryDTO.  # noqa: E501


        :return: The processor_cores_count of this AgentQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._processor_cores_count

    @processor_cores_count.setter
    def processor_cores_count(self, processor_cores_count):
        """Sets the processor_cores_count of this AgentQueryDTO.


        :param processor_cores_count: The processor_cores_count of this AgentQueryDTO.  # noqa: E501
        :type: int
        """

        self._processor_cores_count = processor_cores_count

    @property
    def system_drive(self):
        """Gets the system_drive of this AgentQueryDTO.  # noqa: E501


        :return: The system_drive of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._system_drive

    @system_drive.setter
    def system_drive(self, system_drive):
        """Sets the system_drive of this AgentQueryDTO.


        :param system_drive: The system_drive of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._system_drive = system_drive

    @property
    def processor_clock(self):
        """Gets the processor_clock of this AgentQueryDTO.  # noqa: E501


        :return: The processor_clock of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._processor_clock

    @processor_clock.setter
    def processor_clock(self, processor_clock):
        """Sets the processor_clock of this AgentQueryDTO.


        :param processor_clock: The processor_clock of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._processor_clock = processor_clock

    @property
    def vendor(self):
        """Gets the vendor of this AgentQueryDTO.  # noqa: E501


        :return: The vendor of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._vendor

    @vendor.setter
    def vendor(self, vendor):
        """Sets the vendor of this AgentQueryDTO.


        :param vendor: The vendor of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._vendor = vendor

    @property
    def vendor_serial_number(self):
        """Gets the vendor_serial_number of this AgentQueryDTO.  # noqa: E501


        :return: The vendor_serial_number of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._vendor_serial_number

    @vendor_serial_number.setter
    def vendor_serial_number(self, vendor_serial_number):
        """Sets the vendor_serial_number of this AgentQueryDTO.


        :param vendor_serial_number: The vendor_serial_number of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._vendor_serial_number = vendor_serial_number

    @property
    def vendor_brand_model(self):
        """Gets the vendor_brand_model of this AgentQueryDTO.  # noqa: E501


        :return: The vendor_brand_model of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._vendor_brand_model

    @vendor_brand_model.setter
    def vendor_brand_model(self, vendor_brand_model):
        """Sets the vendor_brand_model of this AgentQueryDTO.


        :param vendor_brand_model: The vendor_brand_model of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._vendor_brand_model = vendor_brand_model

    @property
    def product_name(self):
        """Gets the product_name of this AgentQueryDTO.  # noqa: E501


        :return: The product_name of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._product_name

    @product_name.setter
    def product_name(self, product_name):
        """Sets the product_name of this AgentQueryDTO.


        :param product_name: The product_name of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._product_name = product_name

    @property
    def mac_addresses(self):
        """Gets the mac_addresses of this AgentQueryDTO.  # noqa: E501


        :return: The mac_addresses of this AgentQueryDTO.  # noqa: E501
        :rtype: list[str]
        """
        return self._mac_addresses

    @mac_addresses.setter
    def mac_addresses(self, mac_addresses):
        """Sets the mac_addresses of this AgentQueryDTO.


        :param mac_addresses: The mac_addresses of this AgentQueryDTO.  # noqa: E501
        :type: list[str]
        """

        self._mac_addresses = mac_addresses

    @property
    def ip_addresses(self):
        """Gets the ip_addresses of this AgentQueryDTO.  # noqa: E501


        :return: The ip_addresses of this AgentQueryDTO.  # noqa: E501
        :rtype: list[str]
        """
        return self._ip_addresses

    @ip_addresses.setter
    def ip_addresses(self, ip_addresses):
        """Sets the ip_addresses of this AgentQueryDTO.


        :param ip_addresses: The ip_addresses of this AgentQueryDTO.  # noqa: E501
        :type: list[str]
        """

        self._ip_addresses = ip_addresses

    @property
    def hardware_disks(self):
        """Gets the hardware_disks of this AgentQueryDTO.  # noqa: E501


        :return: The hardware_disks of this AgentQueryDTO.  # noqa: E501
        :rtype: Object
        """
        return self._hardware_disks

    @hardware_disks.setter
    def hardware_disks(self, hardware_disks):
        """Sets the hardware_disks of this AgentQueryDTO.


        :param hardware_disks: The hardware_disks of this AgentQueryDTO.  # noqa: E501
        :type: Object
        """

        self._hardware_disks = hardware_disks

    @property
    def os(self):
        """Gets the os of this AgentQueryDTO.  # noqa: E501


        :return: The os of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._os

    @os.setter
    def os(self, os):
        """Sets the os of this AgentQueryDTO.


        :param os: The os of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._os = os

    @property
    def os_type(self):
        """Gets the os_type of this AgentQueryDTO.  # noqa: E501


        :return: The os_type of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._os_type

    @os_type.setter
    def os_type(self, os_type):
        """Sets the os_type of this AgentQueryDTO.


        :param os_type: The os_type of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._os_type = os_type

    @property
    def windows_serial_number(self):
        """Gets the windows_serial_number of this AgentQueryDTO.  # noqa: E501


        :return: The windows_serial_number of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._windows_serial_number

    @windows_serial_number.setter
    def windows_serial_number(self, windows_serial_number):
        """Sets the windows_serial_number of this AgentQueryDTO.


        :param windows_serial_number: The windows_serial_number of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._windows_serial_number = windows_serial_number

    @property
    def office(self):
        """Gets the office of this AgentQueryDTO.  # noqa: E501


        :return: The office of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._office

    @office.setter
    def office(self, office):
        """Sets the office of this AgentQueryDTO.


        :param office: The office of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._office = office

    @property
    def office_sp(self):
        """Gets the office_sp of this AgentQueryDTO.  # noqa: E501


        :return: The office_sp of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._office_sp

    @office_sp.setter
    def office_sp(self, office_sp):
        """Sets the office_sp of this AgentQueryDTO.


        :param office_sp: The office_sp of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._office_sp = office_sp

    @property
    def office_oem(self):
        """Gets the office_oem of this AgentQueryDTO.  # noqa: E501


        :return: The office_oem of this AgentQueryDTO.  # noqa: E501
        :rtype: bool
        """
        return self._office_oem

    @office_oem.setter
    def office_oem(self, office_oem):
        """Sets the office_oem of this AgentQueryDTO.


        :param office_oem: The office_oem of this AgentQueryDTO.  # noqa: E501
        :type: bool
        """

        self._office_oem = office_oem

    @property
    def office_serial_number(self):
        """Gets the office_serial_number of this AgentQueryDTO.  # noqa: E501


        :return: The office_serial_number of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._office_serial_number

    @office_serial_number.setter
    def office_serial_number(self, office_serial_number):
        """Sets the office_serial_number of this AgentQueryDTO.


        :param office_serial_number: The office_serial_number of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._office_serial_number = office_serial_number

    @property
    def os_num(self):
        """Gets the os_num of this AgentQueryDTO.  # noqa: E501


        :return: The os_num of this AgentQueryDTO.  # noqa: E501
        :rtype: float
        """
        return self._os_num

    @os_num.setter
    def os_num(self, os_num):
        """Sets the os_num of this AgentQueryDTO.


        :param os_num: The os_num of this AgentQueryDTO.  # noqa: E501
        :type: float
        """

        self._os_num = os_num

    @property
    def last_reboot_time(self):
        """Gets the last_reboot_time of this AgentQueryDTO.  # noqa: E501


        :return: The last_reboot_time of this AgentQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._last_reboot_time

    @last_reboot_time.setter
    def last_reboot_time(self, last_reboot_time):
        """Sets the last_reboot_time of this AgentQueryDTO.


        :param last_reboot_time: The last_reboot_time of this AgentQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._last_reboot_time = last_reboot_time

    @property
    def os_version(self):
        """Gets the os_version of this AgentQueryDTO.  # noqa: E501


        :return: The os_version of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._os_version

    @os_version.setter
    def os_version(self, os_version):
        """Sets the os_version of this AgentQueryDTO.


        :param os_version: The os_version of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._os_version = os_version

    @property
    def os_build(self):
        """Gets the os_build of this AgentQueryDTO.  # noqa: E501


        :return: The os_build of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._os_build

    @os_build.setter
    def os_build(self, os_build):
        """Sets the os_build of this AgentQueryDTO.


        :param os_build: The os_build of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._os_build = os_build

    @property
    def office_full_version(self):
        """Gets the office_full_version of this AgentQueryDTO.  # noqa: E501


        :return: The office_full_version of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._office_full_version

    @office_full_version.setter
    def office_full_version(self, office_full_version):
        """Sets the office_full_version of this AgentQueryDTO.


        :param office_full_version: The office_full_version of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._office_full_version = office_full_version

    @property
    def last_login_user(self):
        """Gets the last_login_user of this AgentQueryDTO.  # noqa: E501


        :return: The last_login_user of this AgentQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._last_login_user

    @last_login_user.setter
    def last_login_user(self, last_login_user):
        """Sets the last_login_user of this AgentQueryDTO.


        :param last_login_user: The last_login_user of this AgentQueryDTO.  # noqa: E501
        :type: str
        """

        self._last_login_user = last_login_user

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(AgentQueryDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentQueryDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AgentQueryDTO):
            return True

        return self.to_dict() != other.to_dict()
